@@ -56,6 +56,29 @@ def collect_until_false(
         val = safe_apply(function, val, ctx=ctx)
 
 
+def combinations(lst: VyList, size: int) -> VyList:
+    """Combinations without replacement"""
+    if size == 0:
+        return [[]]
+    elif isinstance(lst, list):
+        return vyxalify(itertools.combinations(lst, size))
+
+    # Infinite LazyLists won't work with itertools.combinations
+    @lazylist
+    def gen():
+        prev_combs = [[]]
+        for elem in lst:
+            new_combs = []
+            for comb in prev_combs:
+                if len(comb) == size - 1:
+                    yield comb + [elem]
+                else:
+                    new_combs.append(comb + [elem])
+            prev_combs += new_combs
+
+    return gen()
+
+
 def concat(vec1: VyList, vec2: VyList, ctx: Context = DEFAULT_CTX) -> VyList:
     """Concatenate two lists/lazylists"""
     if LazyList not in (type(vec1), type(vec2)):
@@ -310,7 +333,7 @@ def levenshtein_distance(s1: str, s2: str) -> int:
 def local_minima(lhs: str) -> List[Union[int, float]]:
     """Find the local minima of a mathematical function using Sympy"""
     x = sympy.symbols("x")
-    d_dx = sympy.diff(sympy.sympify(lhs), x)
+    d_dx = sympy.diff(lhs, x)
     second_dx = sympy.diff(d_dx, x)
     zeros = sympy.solve(d_dx, x)
 
@@ -320,7 +343,7 @@ def local_minima(lhs: str) -> List[Union[int, float]]:
 def local_maxima(lhs: str) -> List[Union[int, float]]:
     """Find the local minima of a mathematical function using Sympy"""
     x = sympy.symbols("x")
-    d_dx = sympy.diff(sympy.sympify(lhs), x)
+    d_dx = sympy.diff(lhs, x)
     second_dx = sympy.diff(d_dx, x)
     zeros = sympy.solve(d_dx, x)
 
@@ -680,7 +703,7 @@ def simplify(value: Any) -> Union[int, float, str, list]:
 def stationary_points(lhs: str) -> List[Union[int, float]]:
     """Returns a list of stationary points of a mathematical function"""
     x = sympy.symbols("x")
-    d_dx = sympy.diff(sympy.sympify(lhs), x)
+    d_dx = sympy.diff(lhs, x)
     zeros = sympy.solve(d_dx, x)
 
     return LazyList(zeros)
